function [D, SR] = audioread(FN, TARGETSR, FORCEMONO)
% [D, SR] = audioread(FN, TARGETSR, FORCEMONO)
%   Read in an audio file, using wavread, mp3read, m4aread, or flacread2 as
%   appropriate. 
% 2010-09-16 Dan Ellis dpwe@ee.columbia.edu

if nargin < 2; TARGETSR = 0; end
if nargin < 3; FORCEMONO = 0; end

[pth,nam,ext] = fileparts(FN);
ext = lower(ext);
if strcmp(ext,'.mp3')
  [D,SR] = mp3read(FN);
elseif strcmp(ext, '.m4a') || strcmp(ext, '.aac') || strcmp(ext, '.mp4')
  [D,SR] = m4aread(FN);
elseif strcmp(ext, '.flac')
  [D,SR] = flacread2(FN);
elseif strcmp(ext, '.wv1') || strcmp(ext, '.wv2') || strcmp(ext, '.shn')
  % nist sphere with shorten - wsj1
  % use dpwelib as a mex file
  [D,SR] = ReadSound(FN);
  D = D'; % returns in rows!
else
  [D,SR] = wavread(FN);
end

if size(D,2) > 1 && FORCEMONO
  D = mean(D,2);
end

if TARGETSR > 0 && SR ~= TARGETSR
  [p,n,e] = fileparts(FN);
  %disp(['*** audioread: resampling ',n,' from ', num2str(SR), ...
  %      ' to ', num2str(TARGETSR)]);
  D = resample(D, TARGETSR, SR);
  SR = TARGETSR;
end

